@@ -1,7 +1,7 @@
 package App::week;
-our $VERSION = "1.06";
+our $VERSION = "1.07";
 
-use v5.14;
+use v5.24;
 use warnings;
 
 use utf8;
@@ -54,7 +54,7 @@ use Getopt::EX::Hashed; {
     has mon  => default => $mon + 1;
 
     has cell_width   => default => undef;
-    has frame        => default => '  ';
+    has frame        => default => "\N{NBSP}\N{NBSP}";
     has frame_height => default => 1;
 
     # option params
@@ -273,7 +273,7 @@ sub display {
 sub h_rule {
     my $obj = shift;
     my $column = shift;
-    my $hr1 = " " x $obj->cell_width;
+    my $hr1 = "\N{NBSP}" x $obj->cell_width;
     my $s = join($obj->frame, '', ($hr1) x $column, '');
     my $rule = $obj->color(FRAME => $s) . "\n";
     print $rule x $obj->frame_height;
@@ -344,7 +344,7 @@ B<week> [ -MI<module> ] [ option ] [ date ]
 
 =head1 VERSION
 
-Version 1.06
+Version 1.07
 
 =head1 DESCRIPTION
 
